From bf4990ffb53e2a0e7b2ec0c7a8a054bdf8a57db5 Mon Sep 17 00:00:00 2001
From: shenyijian <1178253012@qq.com>
Date: Thu, 16 Nov 2023 10:02:13 +0800
Subject: [PATCH] 无人机 -设备分页新增保护区ID查询条件

---
 src/main/java/com/dji/sample/component/mqtt/service/IMessageSenderService.java |   58 +++++++++++++++++++++++++++++++++++++++++++++++++++++++---
 1 files changed, 55 insertions(+), 3 deletions(-)

diff --git a/src/main/java/com/dji/sample/component/mqtt/service/IMessageSenderService.java b/src/main/java/com/dji/sample/component/mqtt/service/IMessageSenderService.java
index 40f7f18..6611ade 100644
--- a/src/main/java/com/dji/sample/component/mqtt/service/IMessageSenderService.java
+++ b/src/main/java/com/dji/sample/component/mqtt/service/IMessageSenderService.java
@@ -2,6 +2,7 @@
 
 import com.dji.sample.component.mqtt.model.CommonTopicResponse;
 import com.dji.sample.component.mqtt.model.ServiceReply;
+import com.fasterxml.jackson.core.type.TypeReference;
 
 /**
  * @author sean.zhou
@@ -26,15 +27,17 @@
     void publish(String topic, int qos, CommonTopicResponse response);
 
     /**
      * Send live streaming start message and receive a response at the same time.
      * @param topic
      * @param response  notification of whether the start is successful.
      * @return
      */
-    ServiceReply publishWithReply(String topic, CommonTopicResponse response);
+    <T> T publishWithReply(Class<T> clazz, String topic, CommonTopicResponse response);
 
     /**
-     * Send live streaming start message and receive a response at the same time.
+     * Send message and receive a response at the same time.
      * @param clazz
      * @param topic
      * @param response
@@ -43,4 +46,53 @@
      * @return
      */
     <T> T publishWithReply(Class<T> clazz, String topic, CommonTopicResponse response, int retryTime);
+
+    /**
+     * Used exclusively for sending messages for services.
+     * @param clazz The generic class for ServiceReply.
+     * @param sn
+     * @param method
+     * @param data
+     * @param bid
+     * @param <T>
+     * @return
+     */
+    <T> ServiceReply<T> publishServicesTopic(TypeReference<T> clazz, String sn, String method, Object data, String bid);
+
+    /**
+     * Used exclusively for sending messages for services, and does not set the received subtype.
+     * @param sn
+     * @param method
+     * @param data
+     * @param bid
+     * @return
+     */
+    ServiceReply publishServicesTopic(String sn, String method, Object data, String bid);
+
+    /**
+     * Used exclusively for sending messages for services.
+     * @param clazz The generic class for ServiceReply.
+     * @param sn
+     * @param method
+     * @param data
+     * @param <T>
+     * @return
+     */
+    <T> ServiceReply<T> publishServicesTopic(TypeReference<T> clazz, String sn, String method, Object data);
+
+    /**
+     * Used exclusively for sending messages for services, and does not set the received subtype.
+     * @param sn
+     * @param method
+     * @param data
+     * @return
+     */
+    ServiceReply publishServicesTopic(String sn, String method, Object data);
+
+    <T> ServiceReply<T> publishRequestsTopic(TypeReference<T> clazz, String sn, String method, Object data, String bid);
+
+    ServiceReply publishRequestsTopic(String sn, String method, Object data, String bid);
+
+    ServiceReply publishRequestsTopic(String sn, String method, Object data);
+
 }
@@ -26,15 +27,17 @@
 
     /**
-     * Send live streaming start message and receive a response at the same time.
+     * Send message and receive a response at the same time.
+     * 发送消息并同时接收响应。
+     * @param clazz
      * @param topic
      * @param response  notification of whether the start is successful.

--
Gitblit v1.9.3